@@ -32,22 +32,6 @@
 #include "callbacks.h"
 
 
-struct ReniceArgs
-{
-	ProcData *procdata;
-	int nice_value;
-};
-
-
-struct KillArgs
-{
-	ProcData *procdata;
-	int signal;
-};
-
-
-
-
 static void
 renice_single_process (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpointer data)
 {
@@ -129,7 +113,7 @@ kill_single_process (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter,
 	gtk_tree_model_get (model, iter, COL_POINTER, &info, -1);
 	g_return_if_fail (info);
 
-	error = kill (info->pid, kill_signal);
+	error = kill (info->pid, args->signal);
 
 	/* success */
 	if(error != -1) return;
@@ -179,12 +163,13 @@ kill_process (ProcData *procdata, int sig)
 	** occurs if you first kill a process and the tree node is removed while
 	** still in the foreach function
 	*/
-	gtk_timeout_remove (procdata->timeout);
+	g_source_remove (procdata->timeout);
 
 	gtk_tree_selection_selected_foreach (procdata->selection, kill_single_process,
 					    &args);
 
-	procdata->timeout = gtk_timeout_add (procdata->config.update_interval,
-					     cb_timeout, procdata);
+	procdata->timeout = g_timeout_add (procdata->config.update_interval,
+					   cb_timeout,
+					   procdata);
 	proctable_update_all (procdata);
 }
